<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Web browser was not specified. Visit the configuration section</source>
        <translation>Browser wurde nicht festgelegt. Bitte in der Konfiguration angeben</translation>
    </message>
    <message>
        <source>Could not spawn Web browser process. Check if the Web browser is functional</source>
        <translation>Konnte den Browser nicht aufrufen. Überprüfen Sie, ob Ihr Browser funktioniert</translation>
    </message>
    <message>
        <source>English</source>
        <translation>Englisch</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation>Italienisch</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>Polnisch</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <source>Force running Kadu (not recommended).</source>
        <translation>Trotzdem starten (nicht empfohlen).</translation>
    </message>
    <message>
        <source>Quit.</source>
        <translation>Beenden.</translation>
    </message>
    <message>
        <source>Please do not run Kadu as a root!
It&apos;s a high security risk!</source>
        <translation>Bitte Kadu aus Sicherheitsgründen nicht als root starten!</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Französisch</translation>
    </message>
    <message>
        <source>Another Kadu is running on this profile but I cannot get its process ID.</source>
        <translation>Andere Instanz von Kadu läuft schon in diesem Profil, aber ich kann seine Porzess-ID nicht finden.</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Mark</source>
        <translation>Mark</translation>
    </message>
    <message>
        <source>Smith</source>
        <translation>Smith</translation>
    </message>
    <message>
        <source>Jimbo</source>
        <translation>Jimbo</translation>
    </message>
    <message>
        <source>Yesterday at </source>
        <translation>Gestern um </translation>
    </message>
    <message>
        <source>dddd at </source>
        <translation>dddd um </translation>
    </message>
    <message>
        <source>%1 weeks ago at </source>
        <translation>vor %1 Wochen um </translation>
    </message>
    <message>
        <source>%1 weeks and %2 days ago at </source>
        <translation>Vor %1 Wochen und %2 Tagen um </translation>
    </message>
    <message>
        <source>%1 weeks and day ago at </source>
        <translation>vor %1 Woche/n und einem Tag um</translation>
    </message>
    <message>
        <source>week ago at </source>
        <translation>Vor einer Woche </translation>
    </message>
    <message>
        <source>week and day ago at </source>
        <translation>Vor einer Woche und einem Tag </translation>
    </message>
    <message>
        <source>week and %2 days ago at </source>
        <translation>Vor einer Woche und %2 Tagen um </translation>
    </message>
    <message>
        <source>d MMMM yyyy at </source>
        <translation>d MMMM yyyy um </translation>
    </message>
    <message>
        <source>Mail client was not specified. Visit the configuration section</source>
        <translation>Es wurde noch kein Email-Programm angegeben. Schauen Sie in der Konfiguration nach</translation>
    </message>
    <message>
        <source>Could not spawn Mail client process. Check if the Mail client is functional</source>
        <translation>Konnte das Email-Programm nicht starten. Überprüfen Sie, ob dieser funktioniert</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Aussehen</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Headers and separators</source>
        <translation>Kopfzeilen und Trenner</translation>
    </message>
    <message>
        <source>Chat header separators height</source>
        <translation>Trenner für Chat-Kopfzeilen-Höhe</translation>
    </message>
    <message>
        <source>Message separators height</source>
        <translation>Trenner für Nachrichten-Höhe</translation>
    </message>
    <message>
        <source>Remove chat header repetitions</source>
        <translation>Entferne Wiederholungen von Chat-Kopfzeilen</translation>
    </message>
    <message>
        <source>Interval between header removal</source>
        <translation>Interval zwischen Kopfzeilen-Entfernung</translation>
    </message>
    <message>
        <source>Server time</source>
        <translation>Serverzeit</translation>
    </message>
    <message>
        <source>Remove server time</source>
        <translation>Entferne Serverzeit</translation>
    </message>
    <message>
        <source>Maximum time difference</source>
        <translation>Maximale Zeitdifferenz</translation>
    </message>
    <message>
        <source>Window title</source>
        <translation>Fenstertitel</translation>
    </message>
    <message>
        <source>Chat window title syntax</source>
        <translation>Syntax für Fenstertitel des Chats</translation>
    </message>
    <message>
        <source>Conference window title prefix</source>
        <translation>Prefix für Konferrenz-Fenstertitel</translation>
    </message>
    <message>
        <source>Conference window title syntax</source>
        <translation>Syntax für den Fenstertitel einer Konferrenz</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Choose your language</source>
        <translation>Wählen Sie Ihre Sprache aus</translation>
    </message>
    <message>
        <source>Updates</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Auf Updates überprüfen</translation>
    </message>
    <message>
        <source>Automatically checks whether a new version is available</source>
        <translation>Überprüfe automatisch, ob es eine neue version gibt</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Programme</translation>
    </message>
    <message>
        <source>WWW browser</source>
        <translation>Webbrowser</translation>
    </message>
    <message>
        <source>Choose your browser</source>
        <translation>Webbrowser auswählen</translation>
    </message>
    <message>
        <source>Specify path</source>
        <translation>Pfad angeben</translation>
    </message>
    <message>
        <source>Konqueror</source>
        <translation>Konqueror</translation>
    </message>
    <message>
        <source>Opera</source>
        <translation>Opera</translation>
    </message>
    <message>
        <source>Mozilla</source>
        <translation>Mozilla</translation>
    </message>
    <message>
        <source>Mozilla Firefox</source>
        <translation>Mozilla Firefox</translation>
    </message>
    <message>
        <source>Dillo</source>
        <translation>Dillo</translation>
    </message>
    <message>
        <source>Galeon</source>
        <translation>Galeon</translation>
    </message>
    <message>
        <source>Safari</source>
        <translation>Safari</translation>
    </message>
    <message>
        <source>Custom browser</source>
        <translation>Eigener Browser</translation>
    </message>
    <message>
        <source>Write specific path to your browser</source>
        <translation>Geben Sie den Pfad zu Ihrem Browser an</translation>
    </message>
    <message>
        <source>e-mail client</source>
        <translation>Email-Programm</translation>
    </message>
    <message>
        <source>Choose your e-mail client</source>
        <translation>Email-Programm auswählen</translation>
    </message>
    <message>
        <source>Choose your email client</source>
        <translation>Wählen Sie Ihr Email-Programm</translation>
    </message>
    <message>
        <source>KMail</source>
        <translation>KMail</translation>
    </message>
    <message>
        <source>Thunderbird</source>
        <translation>Thunderbird</translation>
    </message>
    <message>
        <source>SeaMonkey</source>
        <translation>SeaMonkey</translation>
    </message>
    <message>
        <source>Evolution</source>
        <translation>Evolution</translation>
    </message>
    <message>
        <source>Custom e-mail client</source>
        <translation>Eigenes Email-Programm</translation>
    </message>
    <message>
        <source>Write specific path to your email client</source>
        <translation>Geben Sie den Pfad zu Ihrem Email-Programm an</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Erweitert</translation>
    </message>
    <message>
        <source>Parser</source>
        <translation>Parser</translation>
    </message>
    <message>
        <source>Allow executing commands by parser</source>
        <translation>Ausführen von Befehlen durch den Parser erlauben</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>Debugging</translation>
    </message>
    <message>
        <source>Debugging mask</source>
        <translation>Debugging Maske</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Gadu-Gadu</source>
        <translation>Gadu-Gadu</translation>
    </message>
    <message>
        <source>User data</source>
        <translation>Kontaktinformationen</translation>
    </message>
    <message>
        <source>UIN</source>
        <translation>GG-Nummer (UIN)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Kennwort</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Nick-Name</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Servers properties</source>
        <translation>Servereigenschaften</translation>
    </message>
    <message>
        <source>Use default servers</source>
        <translation>Benutze vorgegebene Server</translation>
    </message>
    <message>
        <source>IP Addresses</source>
        <translation>Adresse IP</translation>
    </message>
    <message>
        <source>You can specify which GG servers to use. Separate every server using semicolon (for example: 91.197.13.26;91.197.13.24;91.197.13.29;91.197.13.6)</source>
        <translation>Hier können Sie angeben, welchen Server GaduGadu Sie nutzen wollen. Trennen Sie die Adressen IP mit Hilfe eines Semmikolons. 
(z.B: 91.197.13.26;91.197.13.24;91.197.13.29;91.197.13.6)</translation>
    </message>
    <message>
        <source>Port to connect to servers</source>
        <translation>Server-Port-Nummer</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>8074</source>
        <translation>8074</translation>
    </message>
    <message>
        <source>443</source>
        <translation>443</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Server Proxy</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Proxy-Server benutzen</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation>Kontate</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Show offline contacts</source>
        <translation>Zeige Kontake, die offline sind</translation>
    </message>
    <message>
        <source>Show contacts that are blocked</source>
        <translation>Zeige blockierte Kontakte</translation>
    </message>
    <message>
        <source>Show contacts which are blocking me</source>
        <translation>Zeige Kontakte, die mich blockieren</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonym</translation>
    </message>
    <message>
        <source>Ignore messages from anonymous users</source>
        <translation>Ignoriere Nachrichten von anonymen Absendern</translation>
    </message>
    <message>
        <source>Ignore messages from anonymous users also in conferences</source>
        <translation>Ignoriere Nachrichten von anonymen Absendern auch in Konferrenzen</translation>
    </message>
    <message>
        <source>Ignore richtext from anonymous users</source>
        <translation>Ignoriere formatierten Text von anonymen Absendern</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Zustand</translation>
    </message>
    <message>
        <source>Private status</source>
        <translation>Nur für Bekannte</translation>
    </message>
    <message>
        <source>When enabled, you&apos;re visible only to users on your list</source>
        <translation>Wenn eingeschaltet, nur Ihre Bekannten können Sie sehen</translation>
    </message>
    <message>
        <source>Descirption</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>On startup, set</source>
        <translation>Beim Start setze</translation>
    </message>
    <message>
        <source>Choose status which will be set on startup</source>
        <translation>Wählen Sie den Zustand aus, der beim Start gesetzt werden soll</translation>
    </message>
    <message>
        <source>Last status</source>
        <translation>Wie zuvor</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Erreichbar</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>Erreichbar (Beschr.)</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Beschäftigt</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Beschäftigt (Beschr.)</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Versteckt</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Versteckt (Beschr.)</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Offline (Beschr.)</translation>
    </message>
    <message>
        <source>On startup, set last description</source>
        <translation>Beim Starten Beschreibung setzten wie vor dem Ausloggen</translation>
    </message>
    <message>
        <source>Last decription will be set on startup</source>
        <translation>Die Beschreibung vom letzten Mal wird beim Start gesetzt</translation>
    </message>
    <message>
        <source>On startup, set description</source>
        <translation>Beim Starten Beschreibung setzen</translation>
    </message>
    <message>
        <source>Define description which will be set on startup</source>
        <translation>Geben Sie bitte die Beschreibung an</translation>
    </message>
    <message>
        <source>On shutdown, keep current description</source>
        <translation>Die Beschreibung beim Logout/Beenden beibehalten</translation>
    </message>
    <message>
        <source>Current description will be set on shutdown</source>
        <translation>Aktuelle Beschreibung wird beim Ausloggen/Beenden beibehalten</translation>
    </message>
    <message>
        <source>On shutdown, set description</source>
        <translation>Beim Aussschalten Beschreibung setzen</translation>
    </message>
    <message>
        <source>Define description which will be set on shutdown</source>
        <translation>Geben Sie die Beschreibung an, die beim Ausloggen gesetzt werden soll</translation>
    </message>
    <message>
        <source>Number of kept descriptions</source>
        <translation>Anzahl der aufzubewahrenden Beschreibungen</translation>
    </message>
    <message>
        <source>Allow using variables in status</source>
        <translation>Erlaube die Nutzung von Variablen im Status</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <source>Choose Qt style</source>
        <translation>Wählen Sie einen Stil Qt aus</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Thema der Symbole</translation>
    </message>
    <message>
        <source>Choose icon theme</source>
        <translation>Wählen Sie ein Symbol-Thema aus</translation>
    </message>
    <message>
        <source>Icon paths</source>
        <translation>Pfad zu den Symbolen</translation>
    </message>
    <message>
        <source>Definie icons paths</source>
        <translation>Geben Sie den Pfad zu den Symbolen an</translation>
    </message>
    <message>
        <source>Show status changing button</source>
        <translation>Zeige Knopf für Zustandsänderungen an</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Farben</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation>Chatfenster</translation>
    </message>
    <message>
        <source>Text edit</source>
        <translation>Text editieren</translation>
    </message>
    <message>
        <source>My messages</source>
        <translation>Meine Nachricht</translation>
    </message>
    <message>
        <source>User messages</source>
        <translation>Nachricht des Benutzers</translation>
    </message>
    <message>
        <source>My font</source>
        <translation>Meine Schriftart</translation>
    </message>
    <message>
        <source>User font</source>
        <translation>Benutze Schriftart</translation>
    </message>
    <message>
        <source>My nick</source>
        <translation>Mein Nick-Name</translation>
    </message>
    <message>
        <source>User nick</source>
        <translation>Nick-Name des Benutzers</translation>
    </message>
    <message>
        <source>Userbox</source>
        <translation>Kontaktliste</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>Hintergrund</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <source>Descriptions font</source>
        <translation>Schriftart für die Beschreibung</translation>
    </message>
    <message>
        <source>Information Panel</source>
        <translation>Informationspanel</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Schriftarten</translation>
    </message>
    <message>
        <source>Font in panel</source>
        <translation>Schriftarten im Panel</translation>
    </message>
    <message>
        <source>New messages notifications</source>
        <translation>Benachrichtigung über neue Nachrichten</translation>
    </message>
    <message>
        <source>Activate windows with new messages</source>
        <translation>Aktiviere Fenster mit neuen Nachrichten</translation>
    </message>
    <message>
        <source>Flash chat title on new message</source>
        <translation>Chat-Titel soll bei neuen Nachrichten blinken</translation>
    </message>
    <message>
        <source>Show number of new messages on chat title</source>
        <translation>Zeige Anzahl neuer Nachrichten im Chat-Titel</translation>
    </message>
    <message>
        <source>Nice date format</source>
        <translation>Datumsformat</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Choose style of chat window</source>
        <translation>Wählen Sie einen Stil für das Chatfenster aus</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation>Smilies</translation>
    </message>
    <message>
        <source>Choose emoticons style</source>
        <translation>Wählen Sie Stil der Smilies aus</translation>
    </message>
    <message>
        <source>Animated</source>
        <translation>Animiert</translation>
    </message>
    <message>
        <source>Static</source>
        <translation>Statisch</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <source>Emoticons theme</source>
        <translation>Smilies-Thema</translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation>Wählen Sie ein Smiley-Thema aus</translation>
    </message>
    <message>
        <source>Emoticons paths</source>
        <translation>Pfad zu Smilies</translation>
    </message>
    <message>
        <source>Define emoticons paths</source>
        <translation>Geben Sie den Pfad zu Smilies an</translation>
    </message>
    <message>
        <source>Advanced...</source>
        <translation>Erweitert...</translation>
    </message>
    <message>
        <source>Display group tabs</source>
        <translation>Zeige Gruppen-Reiter an</translation>
    </message>
    <message>
        <source>Displays group tabs on userbox</source>
        <translation>Zeige Gruppen-Reiter in der Kontaktliste an</translation>
    </message>
    <message>
        <source>Show available contacts in bold</source>
        <translation>Zeige erreichbare Kontakte fett an</translation>
    </message>
    <message>
        <source>Displays users that are not offline using a bold font</source>
        <translation>Zeige alle Kontakte, die nicht offline sind fett an</translation>
    </message>
    <message>
        <source>Align contact icon to</source>
        <translation>Symbole der Kontakte ausrichten</translation>
    </message>
    <message>
        <source>Align icon next to contact name</source>
        <translation>Ausrichten in der Nähe des Kontakt-Namens</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>In der Mitte</translation>
    </message>
    <message>
        <source>Column count</source>
        <translation>Spaltenanzahl</translation>
    </message>
    <message>
        <source>Number of columns displays in userbox</source>
        <translation>Anzahl an Spalten in der Kontaktliste</translation>
    </message>
    <message>
        <source>Tool tip style</source>
        <translation>Stil des Hinweises</translation>
    </message>
    <message>
        <source>Choose userbox tool-tip style</source>
        <translation>Wählen Sie einen Stil für die Hinweise aus</translation>
    </message>
    <message>
        <source>Descriptions</source>
        <translation>Beschreibungen</translation>
    </message>
    <message>
        <source>Show descriptions</source>
        <translation>Zeige Beschreibungen</translation>
    </message>
    <message>
        <source>Displays descriptions in userbox</source>
        <translation>Zeige Beschreibungen in der Kontaktliste an</translation>
    </message>
    <message>
        <source>Allow multiline descriptions</source>
        <translation>Erlaube mehrzeilige Beschreibungen</translation>
    </message>
    <message>
        <source>Dislpays multiline descriptions in userbox</source>
        <translation>Zeige mehrzeilige Beschreibungen in der Kontaktliste an</translation>
    </message>
    <message>
        <source>Use background image</source>
        <translation>Hintergrundbild benutzen</translation>
    </message>
    <message>
        <source>Background file</source>
        <translation>Datei für den Hintergrund</translation>
    </message>
    <message>
        <source>Define background file for userbox</source>
        <translation>Geben Sie die Datei für den Hintergrund an</translation>
    </message>
    <message>
        <source>Display style</source>
        <translation>Darstellgunsstil</translation>
    </message>
    <message>
        <source>Choose userbox background style</source>
        <translation>Wählen Sie eine Hintergrundstil für die Kontanktliste aus</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Kacheln</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>centriert</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>gestreckt</translation>
    </message>
    <message>
        <source>Show information panel</source>
        <translation>Zeige Informationspannel an</translation>
    </message>
    <message>
        <source>Displays information panel below userbox</source>
        <translation>Zeige Informationspannel unter der Kontaktliste an</translation>
    </message>
    <message>
        <source>Show vertical scrollbar</source>
        <translation>Vertikale Bildlaufleiste</translation>
    </message>
    <message>
        <source>Show vertical scrollbar in information panel</source>
        <translation>Zeige vertikale Bildlaufleiste im Informationspannel</translation>
    </message>
    <message>
        <source>Show emoticons in panel</source>
        <translation>Zeige Silies im Ppannel</translation>
    </message>
    <message>
        <source>Show emoticons in information panel</source>
        <translation>Zeige Simlies im Informationspannel&lt;</translation>
    </message>
    <message>
        <source>Choose information panel style</source>
        <translation>Wählen Sie den Stil für den Informationspannel aus</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation>Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>Manage modules</source>
        <translation>Module verwalten</translation>
    </message>
    <message>
        <source>Open chat with...</source>
        <translation>Öffne Chat mit...</translation>
    </message>
    <message>
        <source>Userlist</source>
        <translation>Kontatliste</translation>
    </message>
    <message>
        <source>Remove from userlist</source>
        <translation>Entferne aus der Kontaktliste</translation>
    </message>
    <message>
        <source>Search this user in directory</source>
        <translation>Suche diesen Benutzer im Verzeichnis</translation>
    </message>
    <message>
        <source>Show / hide offline users</source>
        <translation>Zeige/Verstecke Kontakte, die offline sind</translation>
    </message>
    <message>
        <source>Show / hide users without description</source>
        <translation>Zeige/Verstecke Kontakte ohne Beschreibung</translation>
    </message>
    <message>
        <source>New line / send message</source>
        <translation>Neue Zeile / Nachricht senden</translation>
    </message>
    <message>
        <source>Clear chat</source>
        <translation>Chatfenster leeren</translation>
    </message>
    <message>
        <source>Close chat</source>
        <translation>Chat beenden</translation>
    </message>
    <message>
        <source>Bold text</source>
        <translation>Fett</translation>
    </message>
    <message>
        <source>Italic text</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline text</source>
        <translation>Unterstrichen</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Verhalten</translation>
    </message>
    <message>
        <source>Remember chat windows positions</source>
        <translation>Position der Chat-Fenster behalten</translation>
    </message>
    <message>
        <source>Open chat window on new message</source>
        <translation>Öffne das Chat-Fenster bei neuen Nachrichten</translation>
    </message>
    <message>
        <source>Open chat window when comes new message</source>
        <translation>Öffne das Chat-Fenster, wenn eine neue Nachricht eingetroffen ist</translation>
    </message>
    <message>
        <source>Open chat window only when I&apos;m online</source>
        <translation>Öffne Chat-Fenster nur, wenn ich &quot;erreichbar&quot; bin</translation>
    </message>
    <message>
        <source>Open chat window on new message only when online</source>
        <translation>Öffne Chat-Fenster für neue Nachrichten nur, wenn ich &quot;erreichbar&quot; bin</translation>
    </message>
    <message>
        <source>Wait for message delivery</source>
        <translation>Warte auf die Zustellung der Nachricht</translation>
    </message>
    <message>
        <source>Wait for confirmation from server during send messages</source>
        <translation>Warte auf Bestätigung des Servers während des Sendens</translation>
    </message>
    <message>
        <source>&apos;Enter&apos; in chat send message</source>
        <translation>&apos;Enter&apos; im Chat-Fenster sendet die Nachricht</translation>
    </message>
    <message>
        <source>Confirm clearing chat window</source>
        <translation>Das Leeren des Chat-Fensters bestätigen</translation>
    </message>
    <message>
        <source>Ask before clearing chat window</source>
        <translation>Frage nach bevor das Chat-Fenster geleert wird</translation>
    </message>
    <message>
        <source>Save opened windows on exit</source>
        <translation>Speichere geöffnete Fenster beim Beenden</translation>
    </message>
    <message>
        <source>Save opened chat windows when exiting</source>
        <translation>Speichere geöffnete Fenster beim Beenden</translation>
    </message>
    <message>
        <source>Closing</source>
        <translation>Schliessen</translation>
    </message>
    <message>
        <source>Block window close on new message</source>
        <translation>Verhindere das Schliessen eines Chat-Fensters, wenn eine Neue Nachricht eintrifft</translation>
    </message>
    <message>
        <source>Block chat window when comes new message</source>
        <translation>Verhindere das Schliessen eines Chat-Fensters, beim Eintreffen einer neuen Nachricht</translation>
    </message>
    <message>
        <source>Max time to block window close</source>
        <translation>Maximale Dauer der Blockade</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Nchricht</translation>
    </message>
    <message>
        <source>Message pruning</source>
        <translation>Kürzung von Nachrichten</translation>
    </message>
    <message>
        <source>Automatically prune chat messages</source>
        <translation>Kürze Chat-Nachrichten automatisch</translation>
    </message>
    <message>
        <source>If enabled, messages are pruning</source>
        <translation>Wenn eingeschaltet, Nachrichten werden gekürzt</translation>
    </message>
    <message>
        <source>Reduce the number of visible messages in chat window to</source>
        <translation>Begrenze die Anzahl sichtbarer Nachrichten im Chat-Fenster auf</translation>
    </message>
    <message>
        <source>Number of visible messages</source>
        <translation>Anzahl sichtbarer Nachrichten</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>Max image size</source>
        <translation>Maximale Bildgröße</translation>
    </message>
    <message>
        <source>Maximum image size that we want to receive</source>
        <translation>Maximale Bildgröße, die Sie empfangen wollen</translation>
    </message>
    <message>
        <source>Receive images during invisibility</source>
        <translation>Empfangen von Bildern im Zustand &apos;Versteckt&apos;</translation>
    </message>
    <message>
        <source>Receiving images during invisibility is allowed</source>
        <translation>Das Empfangen von Bildern im Zustand &apos;Versteckt&apos; ist eingeschaltet</translation>
    </message>
    <message>
        <source>Limit numbers of image recevied per minute</source>
        <translation>Wie viele Bilder wollen Sie pro Minute empfangen</translation>
    </message>
    <message>
        <source>Define limit of images received per minute</source>
        <translation>Geben Sie einen Limit (Anzahl der zu empfangenden Bilder pro Minute) an</translation>
    </message>
    <message>
        <source>Link folding</source>
        <translation>Links zusammenfalten</translation>
    </message>
    <message>
        <source>Automatically fold links</source>
        <translation>Links automatisch zusammenfalten</translation>
    </message>
    <message>
        <source>Fold links longer than</source>
        <translation>Falte Links zusammen, wenn sie länger sind als</translation>
    </message>
    <message>
        <source>default</source>
        <translation>Voreinstellung</translation>
    </message>
    <message>
        <source>Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name
%r - surname, %m - mobile, %u - uin, %g - group, %o - return _space_ if user doesn&apos;t have us in userlist
%h - gg version, %v - revDNS, %p - port, %e - email, %x - max image size
</source>
        <translation>Syntax: %s - Zustand, %d - Beschreibung, %i - IP, %n - Nick-Name, %a - Alternativer-Nick, %f - Vorname
%r - Nachname, %m - Handy, %u - Nr. GG, %g - Gruppe, %o  - leer, wenn Sie nicht in der Kontaktliste desjenigen sind
%h - Version GG, %v - rev. DNS, %p - Port, %e - Email, %x - maximale Bildgröße
</translation>
    </message>
    <message>
        <source>Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name
%r - surname, %m - mobile, %u - uin, %g - group, %o - return _space_ if user doesn&apos;t have us in userlist
%h - gg version, %v - revDNS, %p - port, %e - email, %x - max image size,
#{protocol} - protocol that triggered event,
#{event} - name of event,
</source>
        <translation>Syntax: %s - Zustand, %d - Beschreibung, %i - IP, %n - Nick-Name, %a - Alternativer-Nick, %f - Vorname
%r - Nachname, %m - Handy, %u - Nr. GG, %g - Gruppe, %o  - leer, wenn Sie nicht in der Kontaktliste desjenigen sind
%h - Version GG, %v - rev. DNS, %p - Port, %e - Email, %x - maximale Bildgröße
#{protocol} - Protokoll, welches dieses Ereignis ausgelöst hat,
#{event} - Ereignisname,</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschaften</translation>
    </message>
    <message>
        <source>Opera (new tab)</source>
        <translation>Opera (neuer Reiter)</translation>
    </message>
    <message>
        <source>Set invisible if last status was &apos;Offline&apos;</source>
        <translation>Setze auf &apos;Versteckt&apos;, wenn Ihr Status zuletzt &apos;Offline&apos; war</translation>
    </message>
    <message>
        <source>Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name
%r - surname, %m - mobile, %u - uin, %g - group, %o - return _space_ if user doesn&apos;t have us in userlist
%h - gg version, %v - revDNS, %p - port, %e - email, %x - max image size,
#{message} - message content,
#{backgroundColor} - background color of message,
#{fontColor} - font color of message,
#{nickColor} - font color of nick,
#{sentDate} - when message was sent,
#{receivedDate} - when message was received,
#{separator} - separator between messages,
&lt;kadu:header&gt;text&lt;/kadu:header&gt; - text will not be displayed in &apos;Remove repeated headers&apos; mode
</source>
        <translation>Syntax: %s - Zustand, %d - Beschreibung, %i - IP, %n - Nick-Name, %a - Alternativer-Nick, %f - Vorname,
%r - Nachname, %m - Handy, %u - Nr. GG, %g - Gruppe, %o - leer, wenn Sie nicht in der Kontaktliste desjenigen sind,
%h - Version GG, %v - rev. DNS,  %p - Port, %e - Email, %x - maximale Bildgröße,
#{message} - Nachricht,
#{backgroundColor} - Farbe für Nachrichtenhintergrund,
#{fontColor} - Farbe der Nachrichtenschrift,
#{nickColor} - Farbe des Nick-Namens,
#{sentDate} - Zeitstempel des Absendens,
#{receivedDate} - Zeitstempel des Empfangs,
#{separator} - Trenner zwischen Nachrichten,
&lt;kadu:header&gt;Text&lt;/kadu:header&gt; - Dieser Text wird nicht angezeigt, wenn &apos;Entfernen der sich wiederholenden Kopfzeilen&apos; eingeschaltet ist</translation>
    </message>
    <message>
        <source>Startup</source>
        <translation>Programmstart</translation>
    </message>
    <message>
        <source>Start on startup</source>
        <translation>Starte beim Programmstart</translation>
    </message>
    <message>
        <source>Automatically start on system startup</source>
        <translation>Starte beim Systemstart</translation>
    </message>
    <message>
        <source>Displays messages from anonymous users without formatting (colors, images, font weight...) Text is plain black.</source>
        <translation>Zeige Nachrichten von Unbekannten ohne Formatierung (Farben, Bilder). Text ist schwarz.</translation>
    </message>
    <message>
        <source>Display dates is nice format, like Today, Yesterday or Friday</source>
        <translation>Zeige Datum im &quot;netten Format&quot; wie &quot;Gestern&quot;, &quot;Morgen&quot; oder &quot;am Freitag&quot;</translation>
    </message>
</context>
<context>
    <name>About</name>
    <message>
        <source>About</source>
        <translation>Über </translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schliessen</translation>
    </message>
    <message>
        <source>A&amp;uthors</source>
        <translation>A&amp;utoren</translation>
    </message>
    <message>
        <source>&amp;Thanks</source>
        <translation>&amp;Dank</translation>
    </message>
    <message>
        <source>&amp;ChangeLog</source>
        <translation>&amp;ChangeLog</translation>
    </message>
    <message>
        <source>&amp;License</source>
        <translation>L&amp;izenz</translation>
    </message>
</context>
<context>
    <name>ChatManager</name>
    <message>
        <source>%1 sends message</source>
        <translation>%1 sendet Nachricht</translation>
    </message>
    <message>
        <source>Clear messages in chat window</source>
        <translation>Leere Verlauf im Chatfenster</translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation>Smiley einfügen</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Bild einfügen</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Unterstrichen</translation>
    </message>
    <message>
        <source>Change color</source>
        <translation>Ändern Farben</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Sende</translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation>Smiley einfügen - aktiviere in der Konfiguration</translation>
    </message>
    <message>
        <source>&amp;Chat</source>
        <translation>&amp;Chat</translation>
    </message>
    <message>
        <source>Search this user in directory</source>
        <translation>Suche diesen Benutzer im Verzeichnis</translation>
    </message>
    <message>
        <source>Ignore user</source>
        <translation>Kontakt ignorieren</translation>
    </message>
    <message>
        <source>Block user</source>
        <translation>Blockiere Benutzer</translation>
    </message>
    <message>
        <source>Anonymous users will be unblocked after restarting Kadu</source>
        <translation>Anonyme benutzer werden nach dem Kadu-Neustart nicht mehr blockiert</translation>
    </message>
    <message>
        <source>Open chat with...</source>
        <translation>Öffne Chat mit...</translation>
    </message>
</context>
<context>
    <name>ChatWidget</name>
    <message>
        <source>Leave conference</source>
        <translation>Konferenz beenden</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Bild einfügen</translation>
    </message>
    <message>
        <source>This file is not readable</source>
        <translation>Die Datei ist nicht lesbar</translation>
    </message>
    <message>
        <source>This file is too big (%1 &gt;= %2)</source>
        <translation>Die Datei ist zu groß (%1 &gt;= %2)</translation>
    </message>
    <message>
        <source>This file is too big for %1.
Do you really want to send this image?
</source>
        <translation>Die Datei ist zu groß für %1.
Wollen Sie diese Datei wirklich senden?</translation>
    </message>
    <message>
        <source>This file is too big for %1 of %2 contacts.
Do you really want to send this image?
Some of them probably will not get it.</source>
        <translation>Die Datei ist für %1 von %2 Benutzern zu groß.
Wollen Sie diese Datei wirklich senden?
Einige von ihnen bekommen sie wahrscheinlich nicht.</translation>
    </message>
    <message>
        <source>Conference with </source>
        <translation>Konferenz mit</translation>
    </message>
    <message>
        <source>Chat with </source>
        <translation>Chat mit</translation>
    </message>
    <message>
        <source>Chat window will be cleared. Continue?</source>
        <translation>Chat-Fenster wird geleert. Fortfahren?</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Sende</translation>
    </message>
    <message>
        <source>Cannot send message while being offline.</source>
        <translation>Kann Nachricht im Offline-Modus nicht senden.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>All messages received in this conference will be ignored
from now on. Are you sure you want to leave this conference?</source>
        <translation>Alle Nachrichten, die in dieser Konferrenz empfangen werden, werden 
von nun an ignoriert. Wollen Sie diese Konferrenz wirklich verlassen?</translation>
    </message>
</context>
<context>
    <name>ChatWindow</name>
    <message>
        <source>New message received, close window anyway?</source>
        <translation>Neue Nachricht empfangen, trotzdem schließen?</translation>
    </message>
</context>
<context>
    <name>ChooseDescription</name>
    <message>
        <source>Select description</source>
        <translation>Beschreibung auswählen</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
</context>
<context>
    <name>ConfigurationWindow</name>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>CustomInput</name>
    <message>
        <source>Undo</source>
        <translation>Schritt zurück</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Schritt vorwärts</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Alles Auswählen</translation>
    </message>
</context>
<context>
    <name>GaduFormater</name>
    <message>
        <source>###IMAGE BLOCKED###</source>
        <translation>###BILD BLOCKIERT###</translation>
    </message>
    <message>
        <source>###IMAGE TOO BIG###</source>
        <translation>###BILD ZU GROSS###</translation>
    </message>
</context>
<context>
    <name>GaduProtocol</name>
    <message>
        <source>I am busy.</source>
        <translation>Ich bin beschäftigt.</translation>
    </message>
    <message>
        <source>Unable to connect, server has not been found</source>
        <translation>Verbindung nicht möglich, Server wurde nicht gefunden</translation>
    </message>
    <message>
        <source>Unable to connect</source>
        <translation>Verbindung nicht möglich</translation>
    </message>
    <message>
        <source>Unable to connect, server has returned unknown data</source>
        <translation>Verbindung nicht möglich, Server lieferte unbekannte Daten zurück</translation>
    </message>
    <message>
        <source>Unable to connect, connection break during reading</source>
        <translation>Verbindung nicht möglich, Abbruch beim Lesen</translation>
    </message>
    <message>
        <source>Unable to connect, connection break during writing</source>
        <translation>Verbindung nicht möglich, Abbruch beim Schreiben</translation>
    </message>
    <message>
        <source>Unable to connect, incorrect password</source>
        <translation>Verbindung nicht möglich. Falsches Passwort</translation>
    </message>
    <message>
        <source>Unable to connect, error of negotiation TLS</source>
        <translation>Verbindung nicht möglich, TLS-Verhandlung schlug fehl</translation>
    </message>
    <message>
        <source>Connection timeout!</source>
        <translation>Verbindungs-Timeout!</translation>
    </message>
    <message>
        <source>Disconnection has occured</source>
        <translation>Verbindung wurde getrennt</translation>
    </message>
    <message>
        <source>UIN or password not set!</source>
        <translation>GG-Nummer (UIN) oder Passwort fehlt!</translation>
    </message>
    <message>
        <source>Please change your email in &quot;Change password / email&quot; window. Leave new password field blank.</source>
        <translation>Ändern Sie Ihre Email-Adresse im &quot;Passwort / Email ändern&quot;-Fenster. Lassen Sie das Feld &quot;Neues Passwort&quot; leer.</translation>
    </message>
    <message>
        <source>Unable to connect, servers are down</source>
        <translation>Verbindung nicht möglich, Server sind offline</translation>
    </message>
    <message>
        <source>Connection will be stopped
Your password is incorrect!</source>
        <translation>Verbindung wird beendet
Dein Passwort stimmt nicht!</translation>
    </message>
    <message>
        <source>Too many connection attempts with bad password!</source>
        <translation>Zu viele Verbindungsversuche mit falschem Passwort!</translation>
    </message>
    <message>
        <source>Connection will be stopped
Too many attempts with bad password</source>
        <translation>Verbindung wird beendet
Zu viel Versuche mit falschem Passwort</translation>
    </message>
    <message>
        <source>Filtered message too long (%1&gt;=%2)</source>
        <translation>Die gefilterte Nachricht ist zu lang (%1&gt;=%2)</translation>
    </message>
    <message>
        <source>Message blocked.</source>
        <translation>Nachricht wurde abgelehnt.</translation>
    </message>
    <message>
        <source>Messagebox full.</source>
        <translation>Nachrichtenbox ist voll.</translation>
    </message>
    <message>
        <source>Message not delivered.</source>
        <translation>Nachricht wurde nicht zugestelt.</translation>
    </message>
</context>
<context>
    <name>GroupsManager</name>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
</context>
<context>
    <name>Ignored</name>
    <message>
        <source>Manage ignored users</source>
        <translation>Verwalte ignorierte Kontakte</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Lösche</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Füge hinzu</translation>
    </message>
    <message>
        <source>Uin</source>
        <translation>GG-Nummer (UIN)</translation>
    </message>
    <message>
        <source>This dialog box allows you to manage your ignored contacts.</source>
        <translation>Dieses Fenster ermöglicht die Verwaltung der zu ignorierenden Kontakte.</translation>
    </message>
    <message>
        <source>Type here the UIN of the person you want to ignore.</source>
        <translation>Geben Sie hier die UIN des Kontaktes ein, den Sie ignorieren wollen.</translation>
    </message>
    <message>
        <source>Uin:</source>
        <translation>GG-Nummer (UIN):</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
</context>
<context>
    <name>ImageDialog</name>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
</context>
<context>
    <name>Kadu</name>
    <message>
        <source>Configuration</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation>Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>Kadu: %1</source>
        <translation>Kadu: %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>Kadu &amp;verlassen</translation>
    </message>
    <message>
	<source>Show Pending Messages</source>
	<translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify about user</source>
        <translation>Benachrichtige über Kontakt</translation>
    </message>
    <message>
        <source>Offline to user</source>
        <translation>Offline für Kontakt</translation>
    </message>
    <message>
        <source>Manage &amp;ignored</source>
        <translation>Verwalte die &amp;Ignoriertenliste</translation>
    </message>
    <message>
        <source>Personal information</source>
        <translation>Persönliche Daten</translation>
    </message>
    <message>
        <source>H&amp;elp</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>A&amp;bout...</source>
        <translation>Ü&amp;ber...</translation>
    </message>
    <message>
        <source>&amp;Hide Kadu</source>
        <translation>Ve&amp;rstecke Kadu</translation>
    </message>
    <message>
        <source>Private</source>
        <translation>Nur für Bekannte</translation>
    </message>
    <message>
        <source>I&amp;mport / Export userlist</source>
        <translation>I&amp;mportieren / Exportieren der Benutzerliste</translation>
    </message>
    <message>
        <source>Hide description</source>
        <translation>Beschreibung verstecken</translation>
    </message>
    <message>
        <source>Search user in directory</source>
        <translation>Suche nach Kontakt im Verzeichnis</translation>
    </message>
    <message>
        <source>Copy description</source>
        <translation>Beschreibung kopieren</translation>
    </message>
    <message>
        <source>Copy personal info</source>
        <translation>Persönliche Daten kopieren</translation>
    </message>
    <message>
        <source>Contact: %a[ (%u)]
[First name: %f
][Last name: %r
][Mobile: %m
]</source>
        <translation>Kontakt: %a[ (%u)]
[Vorname: %f
][Nachname: %r
][Handy: %m
]</translation>
    </message>
    <message>
        <source>Open description link in browser</source>
        <translation>Öffne den Link im Browser</translation>
    </message>
    <message>
        <source>Write email message</source>
        <translation>Email-Nachricht schreiben</translation>
    </message>
    <message>
        <source>Search in directory</source>
        <translation>Suche im Verzeichnis</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Lösche</translation>
    </message>
    <message>
        <source>Hide offline users</source>
        <translation>Verstecke Kontakte, die offline sind</translation>
    </message>
    <message>
        <source>Show offline users</source>
        <translation>Zeige Kontakte, die offline sind</translation>
    </message>
    <message>
        <source>Hide users without description</source>
        <translation>Verstecke Kontate ohne Beschreibung</translation>
    </message>
    <message>
        <source>Show users without description</source>
        <translation>Zeige Kontate ohne Beschreibung</translation>
    </message>
    <message>
        <source>Show only online or description buddies</source>
        <translation>Zeige nur Kontakte, die online sind oder Beschreibung haben</translation>
    </message>
    <message>
        <source>Show all users</source>
        <translation>Zeige alle Kontakte</translation>
    </message>
    <message>
        <source>Recent chats...</source>
        <translation>Letzte Unterhaltungen...</translation>
    </message>
    <message>
        <source>No closed chats found</source>
        <translation>Keine geschlossenen Chats gefunden</translation>
    </message>
    <message>
        <source>Contact data</source>
        <translation>Kontaktinformationen</translation>
    </message>
    <message>
        <source>Me</source>
        <translation>Ich</translation>
    </message>
    <message>
        <source>Change status</source>
        <translation>Zustand wechseln</translation>
    </message>
    <message>
        <source>Selected users:
%0will be deleted. Are you sure?</source>
        <translation>Ausgewählte Benutzer:
%0werden gelöscht. Sind Sie sicher?</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menü</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Erreichbar</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>Erreichbar (Beschr.)</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Beschäftigt</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Beschäftigt (Beschr.)</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Versteckt</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Versteckt (Beschr.)</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Offline (Beschr.)</translation>
    </message>
</context>
<context>
    <name>KaduMainWindow</name>
    <message>
        <source>Create new toolbar</source>
        <translation>Neue Werkzeugleiste erstellen</translation>
    </message>
</context>
<context>
    <name>KaduTabBar</name>
    <message>
        <source>Add new group</source>
        <translation>Neue Gruppe hinzufügen</translation>
    </message>
    <message>
        <source>Name of new group:</source>
        <translation>Name der neuen Gruppe:</translation>
    </message>
    <message>
        <source>Add to group %1</source>
        <translation>Füge zur Gruppe %1 hinzu</translation>
    </message>
    <message>
        <source>Move to group %1</source>
        <translation>Verschiebe zu Gruppe %1</translation>
    </message>
</context>
<context>
    <name>KaduTextBrowser</name>
    <message>
        <source>Save image</source>
        <translation>Bild speichern</translation>
    </message>
    <message>
        <source>File already exists. Overwrite?</source>
        <translation>Datei existiert bereits. Überschreiben?</translation>
    </message>
    <message>
        <source>Cannot save image: %1</source>
        <translation>Kann Datei: %1 nicht speichern</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Copy Link</source>
        <translation>Link kopieren</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation>Bild kopieren</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Bild speichern</translation>
    </message>
</context>
<context>
    <name>MainConfigurationWindow</name>
    <message>
        <source>None</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>Nciht gefunden</translation>
    </message>
    <message>
        <source>Kadu configuration</source>
        <translation>Konfiguration Kadu</translation>
    </message>
    <message>
        <source>Advenced chat&apos;s look configuration</source>
        <translation>Erweiterte Konfiguration der Chat-Darstellung</translation>
    </message>
    <message>
        <source>Your message</source>
        <translation>Ihre Nachricht</translation>
    </message>
    <message>
        <source>Message from Your friend</source>
        <translation>Nachricht von Ihrem Freund</translation>
    </message>
</context>
<context>
    <name>MessageBox</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nein</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
</context>
<context>
    <name>ModulesDialog</name>
    <message>
        <source>Manage Modules</source>
        <translation>Verwalte Module</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Static</source>
        <translation>Statisch</translation>
    </message>
    <message>
        <source>Loaded</source>
        <translation>Geladen</translation>
    </message>
    <message>
        <source>Module name</source>
        <translation>Modulname</translation>
    </message>
    <message>
        <source>Module type</source>
        <translation>Typ des Moduls</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Zustand</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <source>Dynamic</source>
        <translation>Dynamisch</translation>
    </message>
    <message>
        <source>Not loaded</source>
        <translation>Nicht geladen</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>&lt;b&gt;Module:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Depends on:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Conflicts with:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Provides:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Author:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Version:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Description:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Module:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Hängt ab von:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Im Konflikt 
mit:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Bringt mit:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Autor:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Verion&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Beschreibung:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Hide base modules</source>
        <translation>Verstecke Standardmodule</translation>
    </message>
    <message>
        <source>&lt;b&gt;Module: &lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Depends on: &lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Conflicts with: &lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Provides: &lt;/b&gt;%4&lt;br/&gt;&lt;b&gt;Author: &lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Version: &lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Description: &lt;/b&gt;%7</source>
        <translation>&lt;b&gt;Das Modul: &lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Hängt ab von: &lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Im Konflikt mit: &lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Frührt mit: &lt;/b&gt;&lt;br/&gt;&lt;b&gt;Autor: &lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Version: &lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Beschreibung: &lt;/b&gt;%7</translation>
    </message>
    <message>
        <source>This dialog box allows you to manage installed modules. Modules are responsible for numerous vital features like playing sounds or message encryption.
You can load (or unload) them by double-clicking on their names.</source>
        <translation>In diesem Fenster können sie die installierten Module verwalten. Module sorgen dafür, dass diese Anwendung erweitert wird wie z.B. um das Abspielen von Klängen, Verschlüsselung von Nachrichten etc.
Sie können die Module starten oder einbinden, indem Sie den Namen des Moduls Doppelklicken.</translation>
    </message>
</context>
<context>
    <name>ModulesManager</name>
    <message>
        <source>&amp;Manage Modules</source>
        <translation>&amp;Verwalte Module</translation>
    </message>
    <message>
        <source>Required module %1 was not found</source>
        <translation>Erforderliches Modul %1 wurde nicht gefunden</translation>
    </message>
    <message>
        <source>Module %1 is already active</source>
        <translation>Modul %1 ist bereits aktiv</translation>
    </message>
    <message>
        <source>Cannot load %1 module library.:
%2</source>
        <translation>Kann die Bibliothek %1 mit Modulen nicht laden:
%2</translation>
    </message>
    <message>
        <source>Module %1 cannot be deactivated because it is used now</source>
        <translation>Modul %1 kann nicht deaktiviert werden, weil es gerade benutzt wird</translation>
    </message>
    <message>
        <source>Module %1 conflicts with: %2</source>
        <translation>Modul %1 kollidiert mit: %2</translation>
    </message>
    <message>
        <source>Cannot find required functions in module %1.
Maybe it&apos;s not Kadu-compatible Module.</source>
        <translation>Ich kann die verlangte Funktion im Modul %1 nicht finden.
Vielleicht ist es kein Kadu-Modul.</translation>
    </message>
    <message>
        <source>Module initialization routine for %1 failed.</source>
        <translation>Initialisationroutinen für Modul %1 fehlgeschlagen.</translation>
    </message>
</context>
<context>
    <name>OpenChatWith</name>
    <message>
        <source>Open chat with...</source>
        <translation>Öffne Chat mit...</translation>
    </message>
    <message>
        <source>Userlist</source>
        <translation>Kontatliste</translation>
    </message>
    <message>
        <source>UIN or nick</source>
        <translation>Nummer GG oder Nick</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>PathListEdit</name>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
</context>
<context>
    <name>PathListEditWindow</name>
    <message>
        <source>Select paths</source>
        <translation>Pfade auswählen</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Füge hinzu</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>Choose a directory</source>
        <translation>Wählen Sie ein Verzeichnis</translation>
    </message>
</context>
<context>
    <name>PersonalInfoDialog</name>
    <message>
        <source>Personal Information</source>
        <translation>Persönliche Daten</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Vorname</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Nachname</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Geschlecht</translation>
    </message>
    <message>
        <source>Male</source>
        <translation>Männlich</translation>
    </message>
    <message>
        <source>Female</source>
        <translation>Weiblich</translation>
    </message>
    <message>
        <source>Birthyear</source>
        <translation>Geburtsjahr</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Stadt</translation>
    </message>
    <message>
        <source>Family Name</source>
        <translation>Geburtsname</translation>
    </message>
    <message>
        <source>Family City</source>
        <translation>Geburtsort</translation>
    </message>
    <message>
        <source>This dialog box allows you to manage your personal information, for example your name, surname or age.</source>
        <translation>Dieses Fenster ermöglicht Ihnen die Verwaltung Ihrer persönlichen Daten, wie z.B. Name oder Alter.</translation>
    </message>
    <message>
        <source>Your personal information</source>
        <translation>Ihre persönlichen Daten</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>S&amp;peichern</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>&amp;Erneut laden</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Suche</translation>
    </message>
    <message>
        <source>&amp;Next results</source>
        <translation>&amp;Nächstes</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Vorname</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Nachname</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Geschlecht</translation>
    </message>
    <message>
        <source>Male</source>
        <translation>Mann</translation>
    </message>
    <message>
        <source>Female</source>
        <translation>Frau</translation>
    </message>
    <message>
        <source>Birthyear</source>
        <translation>Geburtsjahr</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Stadt</translation>
    </message>
    <message>
        <source>Uin</source>
        <translation>GG-Nummer (UIN)</translation>
    </message>
    <message>
        <source>Search criteria</source>
        <translation>Suchkriterien</translation>
    </message>
    <message>
        <source>&amp;Personal data</source>
        <translation>&amp;Persönliche Daten</translation>
    </message>
    <message>
        <source>Search using the personal data typed above (name, nickname)...</source>
        <translation>Suche nach Personen mit den oben angegebenen Daten (Name, Benutzername)...</translation>
    </message>
    <message>
        <source>&amp;Uin number</source>
        <translation>GG-&amp;Nummer (UIN)</translation>
    </message>
    <message>
        <source>Search for this UIN exclusively</source>
        <translation>Suche nur nach der angegebene GG-Nummer (UIN)</translation>
    </message>
    <message>
        <source>Only active users</source>
        <translation>Nur Erreichbare</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Zustand</translation>
    </message>
    <message>
        <source>Birth year</source>
        <translation>Geburtsjahr</translation>
    </message>
    <message>
        <source>Searching...</source>
        <translation>Suche...</translation>
    </message>
    <message>
        <source>Done searching</source>
        <translation>Suche beendet</translation>
    </message>
    <message>
        <source>from</source>
        <translation>von</translation>
    </message>
    <message>
        <source>to</source>
        <translation>zum</translation>
    </message>
    <message>
        <source>There were no results of your search</source>
        <translation>Ihre Suche verlief leider ergebnislos</translation>
    </message>
    <message>
        <source>Search user in directory</source>
        <translation>Suche nach Kontakt im Verzeichnis</translation>
    </message>
    <message>
        <source>Clear results</source>
        <translation>Ergebnisse löschen</translation>
    </message>
    <message>
        <source>Add selected user</source>
        <translation>Füge ausgewählten Benutzer hinzu</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>&amp;Chat</source>
        <translation>&amp;Chat</translation>
    </message>
    <message>
        <source>Cannot search contacts in offline mode</source>
        <translation>Kann offline nicht nach Kontakten suchen</translation>
    </message>
</context>
<context>
    <name>SelectFile</name>
    <message>
        <source>Insert image</source>
        <translation>Bild einfügen</translation>
    </message>
    <message>
        <source>Select File</source>
        <translation>Datei auswählen</translation>
    </message>
    <message>
        <source>Select audio File</source>
        <translation>Klangdatei auswählne</translation>
    </message>
</context>
<context>
    <name>SelectFont</name>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
</context>
<context>
    <name>SyntaxEditor</name>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Unable to remove syntax: %1</source>
        <translation>Kann die Syntax %1 nicht entfernen</translation>
    </message>
</context>
<context>
    <name>SyntaxEditorWindow</name>
    <message>
        <source>Kadu syntax editor</source>
        <translation>Fehler in der Kadu-Syntax</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>New syntax name</source>
        <translation>Name für die Neuen Syntax</translation>
    </message>
    <message>
        <source>Enter new syntax name</source>
        <translation>Geben Sie den Namen für die neue Syntax an</translation>
    </message>
    <message>
        <source>Syntax %1 already exists and cannot be modified</source>
        <translation>Syntax %1 existiert bereits und kann nicht modifiziert werden</translation>
    </message>
    <message>
        <source>Overwrite %1 syntax?</source>
        <translation>Syntax %1 überschrieben?</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Speichern unter...</translation>
    </message>
</context>
<context>
    <name>TokenDialog</name>
    <message>
        <source>Read this code ...</source>
        <translation>Lies den Kode ab...</translation>
    </message>
    <message>
        <source>and type here</source>
        <translation>und gib ihn hier ein</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
</context>
<context>
    <name>ToolBar</name>
    <message>
        <source>Delete toolbar</source>
        <translation>Werkzeugleiste löschen</translation>
    </message>
    <message>
        <source>Add new button</source>
        <translation>Neue Schaltfläche hinzufügen</translation>
    </message>
    <message>
        <source>Remove toolbar?</source>
        <translation>Toolbar entfernen?</translation>
    </message>
    <message>
        <source>No items to add found</source>
        <translation>Keine Einträge zum Hinzufügen gefunden</translation>
    </message>
    <message>
        <source>Show text label</source>
        <translation>Textfläche zeigen</translation>
    </message>
    <message>
        <source>Delete button</source>
        <translation>Schaltfläche entfernen</translation>
    </message>
    <message>
        <source>Create new toolbar</source>
        <translation>Neue Werkzeugleiste erstellen</translation>
    </message>
    <message>
        <source>Block toolbars</source>
        <translation>Werkzeugleisten blockieren</translation>
    </message>
</context>
<context>
    <name>Updates</name>
    <message>
        <source>The newest Kadu version is %1</source>
        <translation>Die neuste Version von Kadu ist %1</translation>
    </message>
</context>
<context>
    <name>UserBox</name>
    <message>
        <source>Hide descriptions</source>
        <translation>Verstecke Beschreibungen</translation>
    </message>
    <message>
        <source>Show descriptions</source>
        <translation>Zeige Beschreibungen</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Zustände</translation>
    </message>
    <message>
        <source>Nicks, case insensitive</source>
        <translation>Nick-Namen, mit Groß- und Kleinschreibung</translation>
    </message>
    <message>
        <source>Nicks</source>
        <translation>NIck-Namen</translation>
    </message>
    <message>
        <source>User management</source>
        <translation>Benutzerverwaltung</translation>
    </message>
</context>
<context>
    <name>UserInfo</name>
    <message>
        <source>User info on %1</source>
        <translation>Informationen zu %1</translation>
    </message>
    <message>
        <source>Uin</source>
        <translation>GG-Nummer (UIN)</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Zustand</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>AltNick</source>
        <translation>Alternativer Benutzername</translation>
    </message>
    <message>
        <source>First name</source>
        <translation>Vorname</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Nachname</translation>
    </message>
    <message>
        <source>Mobile</source>
        <translation>Mobil</translation>
    </message>
    <message>
        <source>Address IP and Port</source>
        <translation>IP-Adresse und Port</translation>
    </message>
    <message>
        <source>Protocol version</source>
        <translation>Protokoll-Version</translation>
    </message>
    <message>
        <source>DNS name</source>
        <translation>DNS-Name</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>(Unknown)</source>
        <translation>(unbekannt)</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Block user</source>
        <translation>Blockiere Kontakt</translation>
    </message>
    <message>
        <source>Offline to user</source>
        <translation>Offline für Kontakt</translation>
    </message>
    <message>
        <source>Notify about status changes</source>
        <translation>Benachrichtige über Zustandsänderung</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Andere</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation>Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Füge hinzu</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <source>Altnick field cannot be empty.</source>
        <translation>Das Feld &quot;Alternativer Benutzername&quot; darf nicht leer sein.</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <source>This dialog box allows you to view and edit information about the selected contact.</source>
        <translation>Dieses Fenster ermöglicht Ihnen das Anzeigen und Ändern der Kontaktdaten.</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Gruppen</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>Neue Gruppe hinzufügen</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is prohibited</source>
        <translation>&apos;%1&apos; ist nicht erlaubt</translation>
    </message>
    <message>
        <source>This group already exists!</source>
        <translation>Diese Gruppe existiert bereits!</translation>
    </message>
    <message>
        <source>Numbers are prohibited</source>
        <translation>Zahlen sind nicht erlaubt</translation>
    </message>
    <message>
        <source>Change icon</source>
        <translation>Symbol ändern</translation>
    </message>
    <message>
        <source>Delete icon</source>
        <translation>Symbol löschen</translation>
    </message>
    <message>
        <source>Choose an icon</source>
        <translation>Wählen Sie ein Symbol aus</translation>
    </message>
    <message>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Symbole (*.png *.xmp *.jpg)</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Symbol:</translation>
    </message>
    <message>
        <source>User known as %1 with that UIN is already in userlist.</source>
        <translation>Kontakt %1 mit dieser Nr. GG ist bereits in Ihrer Kontaktliste.</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Erreichbar</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>Erreichbar (Beschr.)</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Beschäftigt</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Beschäftigt (Beschr.)</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Versteckt</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Versteckt (Beschr.)</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Offline (Beschr.)</translation>
    </message>
</context>
<context>
    <name>UserStatus</name>
    <message>
        <source>Online</source>
        <translation>Erreichbar</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>Erreichbar (Beschr.)</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Beschäftigt</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Beschäftigt (Beschr.)</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Versteckt</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Versteckt (Beschr.)</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Offline (Beschr.)</translation>
    </message>
    <message>
        <source>Blocking</source>
        <translation>Blockt</translation>
    </message>
</context>
<context>
    <name>UserlistImportExport</name>
    <message>
        <source>Import / export userlist</source>
        <translation>Importiere / Exportiere Kontaktliste</translation>
    </message>
    <message>
        <source>This dialog box allows you to import and export your buddy list to a server or a file.</source>
        <translation>Dieses Dialogfeld erlaubt Ihnen, Ihre Kontaktliste auf den/vom Server oder in eine/aus einer Datei zu exportieren/importieren.</translation>
    </message>
    <message>
        <source>Import userlist</source>
        <translation>Importiere Kontakt-Liste</translation>
    </message>
    <message>
        <source>UIN</source>
        <translation>GG-Nummer (UIN)</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Disp. nick</source>
        <translation>Zeige den Benutzernamen</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Vorname</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Nachname</translation>
    </message>
    <message>
        <source>Mobile no.</source>
        <translation>Mobil-Nr.</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>&amp;Fetch userlist</source>
        <translation>&amp;Hole Kontaktliste</translation>
    </message>
    <message>
        <source>&amp;Import from file</source>
        <translation>&amp;Import aus Datei</translation>
    </message>
    <message>
        <source>&amp;Save results</source>
        <translation>Ergebnisse &amp;speichern</translation>
    </message>
    <message>
        <source>&amp;Merge results</source>
        <translation>Ergebnisse &amp;zusammenführen</translation>
    </message>
    <message>
        <source>Export userlist</source>
        <translation>Exportiere Kontaktliste </translation>
    </message>
    <message>
        <source>%1 entries will be exported</source>
        <translation>%1 Einträge werden exportiert</translation>
    </message>
    <message>
        <source>Se&amp;nd userlist</source>
        <translation>Kontaktliste &amp;senden</translation>
    </message>
    <message>
        <source>&amp;Delete userlist</source>
        <translation>Kontaktliste &amp;löschen</translation>
    </message>
    <message>
        <source>&amp;Export to file</source>
        <translation>&amp;Exportiere in Datei</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The import userlist from file was unsuccessful</source>
        <translation>Das Importieren aus der Datei wurde wegen eines Fehlers beendet</translation>
    </message>
    <message>
        <source>Your userlist has been successfully exported to file</source>
        <translation>Die Kontaktliste wurde erfolgreich in die Datei exportiert</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The export userlist to file was unsuccessful</source>
        <translation>Das Exportieren der Kontaktliste in die Datei ist misslungen</translation>
    </message>
    <message>
        <source>Your userlist has been successfully exported to server</source>
        <translation>Die Kontaktliste wurde auf den Server exportiert</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The export was unsuccessful</source>
        <translation>Das Exportieren der Kontakliste auf den Server ist misslungen</translation>
    </message>
    <message>
        <source>Your userlist has been successfully deleted on server</source>
        <translation>Ihre Kontaktliste ist erfolgreich vom Server gelöscht worden</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The delete userlist on server was unsuccessful</source>
        <translation>Die Anwendung hat einen Fehler zurückgemeldet.
Das Löschen der Kontaktliste vom Server ist misslungen</translation>
    </message>
    <message>
        <source>Cannot import user list from server in offline mode</source>
        <translation>Ich kann die Kontaktliste vom Server nicht importieren, wenn sie offline sind</translation>
    </message>
    <message>
        <source>This operation will delete your current user list. Are you sure you want this?</source>
        <translation>Diese Aktion löscht Ihre jetzige Kontaktliste. Sind Sie sicher, dass Sie das wollen?</translation>
    </message>
    <message>
        <source>Cannot export user list to server in offline mode</source>
        <translation>Ich kann die Kontaktliste nicht auf den Server exportieren, wenn sie offline sind</translation>
    </message>
    <message>
        <source>Cannot clear user list on server in offline mode</source>
        <translation>Ich kann die Kontaktliste auf dem Server nicht löschen, solange Sie offline sind</translation>
    </message>
    <message>
        <source>File exists. Are you sure you want to overwrite it?</source>
        <translation>Datei exisitert. Sind Sie sicher, dass Sie es überschreiben wollen?</translation>
    </message>
</context>
</TS>
